<h1 align="center"><b>- S T E R R A -</b></h1>
<h3 align="center">A unique SOCMINT tool to get informations on an instagram account<br>from its following | followers</h4>
<h1 align="center">
    <a href="https://www.instagram.com"><img src="https://img.shields.io/badge/Instagram-inactive?logo=data:image/svg+xml;base64, "></a>
    <a href="https://github.com/novitae/sterraxcyl"><img src="https://img.shields.io/badge/Sterra-2.2-8787ff"></a>
    <a href="https://en.wikipedia.org/wiki/GNU_General_Public_License"><img src="https://img.shields.io/badge/License-GPL3.0-inactive"></a>
    <a href="https://www.python.org/downloads/"><img src="https://img.shields.io/badge/Python-3.x-00af87"></a>
    <a href="https://github.com/novitae/sterraxcyl/wiki"><img src="https://img.shields.io/badge/🌐-Wiki-inactive"></a>
</h1>

➡️ **Sterra's main function is to export lists of followers | following | mutuals from Instagram to excel | csv | json with informations on accounts**
![](https://i.imgur.com/9N8I7ak.png)
*[National Geographic](https://www.instagram.com/natgeo/) following list under excel format*

➡️ **It can also analyse exported lists to search for personnal account (which means estimating which accounts are in the close circle of your target)**
![](https://i.imgur.com/Vi6Xw6B.png)

<div align="center">
    <table>
        <tr>
            <td><a href="https://www.instagram.com/dregufevia3/">dregufevia3</a></td>
            <td><a href="https://www.instagram.com/rute_alves3/">rute_alves3</a></td>
            <td><a href="https://www.instagram.com/hicham_rt/">hicham_rt</a></td>
            <td><a href="https://www.instagram.com/ricardo.piloto.7/">ricardo.piloto.7</a></td>
            <td><a href="https://www.instagram.com/j_nyusi_258/">j_nyusi_258/</a></td>
        </tr>
        <tr>
            <td><a href="https://www.instagram.com/barbaravara/">barbaravara</a></td>
            <td><a href="https://www.instagram.com/pregufe/">pregufe</a></td>
            <td><a href="https://www.instagram.com/delgad0_andre/">delgad0_andre</a></td>
            <td><a href="https://www.instagram.com/dgh1/">dgh1</a></td>
            <td><a href="https://www.instagram.com/rodrigoptf/">rodrigoptf</a></td>
        </tr>
    </table>
</div>

*Personnal accounts analysis for [Christiano Ronaldo](https://www.instagram.com/cristiano/) following list. All the upper accounts are followed by Ronaldo himself. Data exportable.*

➡️ **Finaly, it can compare two lists in order to find commons or not commons users**
![](https://i.imgur.com/mWpZQn2.png)
*Common usernames between [Kylie Jenner](https://www.instagram.com/kyliejenner/) following list and [Travis Scott](https://www.instagram.com/travisscott/) following list. Data exportable.*
# 📥 Installation
```python
pip install sterra
# or
git clone https://github.com/novitae/sterraxcyl/
cd sterraxcyl
python setup.py install
```
# 🌐 Wiki
| [**Wiki**](https://github.com/novitae/sterraxcyl/wiki) | The home page of the Wiki |
| :---: | :---: |
| [**Basic Usage Wiki**](https://github.com/novitae/sterraxcyl/wiki/Basic-usage) | **The Wiki page to start using Sterra** |

# 📙 More
- This tool have been made as an alternative of the Chrome extension [__export List of Followers from Instagram__](https://chrome-stats.com/d/hcdbfckhdcpepllecbkaaojfgipnpbpb) that has been killed for some ""[reasons](https://s.keepmeme.com/files/en_posts/20201223/delete-this-mark-zuckerberg-holding-gun-meme.jpg)"". It was made to export data on the accounts as sterra's export module does. This is the main inspiration.\
I was using it to do manually the job of sterra's analyse module.
- The export module uses the Instagram GraphQL API to get the lists of usernames. The architecture of it is based on the [__get_instagram_followers-following_list__](https://github.com/francozanardi/get_instagram_followers-following_list/) one.
- My twitter messages are open -> [*meakaaet*](https://twitter.com/meakaaet)
- *Sterra and Sterraxcyl are the same program; Sterraxcyl is the old name, but it was weird afterall, so i changed it as i could to Sterra*
